// /******************************************/
// /* Put before the time loop               */ 
// /******************************************/
// 
//  Control system setup.
//  Requires dictionary constant/probeLocations.
// 

IOdictionary pLocs
(
IOobject
(
"probeLocations",
runTime.constant(),
mesh,
IOobject::MUST_READ,
IOobject::NO_WRITE
)
);


// Probes
const pointField& probeLocations(pLocs.lookup("probeLocations")); // create pointer to probes
labelList probeCells(probeLocations.size(), -1);                                 // build cell ID list 
List<double> Tsensor(probeLocations.size(),  0.0);                          // create array for storing temperature readings 
// locate probe cells and take first reading

forAll(probeLocations, pI) 
{
probeCells[pI] = mesh.findCell(probeLocations[pI]); 
if ((int)probeCells[pI]>=0) Tsensor[pI] = T[probeCells[pI]]; 
}
reduce( Tsensor, sumOp<List<double> >() ); // Communicate probe readings between processors

// Control system parameters
double CS_Tmed; // variable for storing measured mean temperature
dimensionedScalar CS_setPoint        // set point
(    pLocs.lookup("CS_setPoint")    );
dimensionedScalar CS_gain              // gain
(    pLocs.lookup("CS_gain")          );

/******************************************/  
// /*--------------------------------*- C++ -*----------------------------------*\
// | =========                 |                                                 |
// | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
// |  \\    /   O peration     | Version:  1.6                                   |
// |   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
// |    \\/     M anipulation  |                                                 |
// \*---------------------------------------------------------------------------*/
// FoamFile
// {
//     version     2.0;
//     format      ascii;
//     class       dictionary;
//     location    "constant";
//     object      probeLocations;
// }
// 
// // Sistema de control
// 
// //    Posiciones de los sensores (cantidad arbitraria; mide la Tmed[C] de estos sensores)
// probeLocations 
// (
// ( 0.2 -0.01 0)
// ( 0.2  0.0 0)
// ( 0.2  0.01 0)
// );
// 
// //    Tipo de sensores
// fields
// (
// T  // termocuplas
// );
// 
// //    Parametros del sistema de control (solo proporcional)
// //
// CS_setPoint	CS_setPoint   	[0 0 0 0 0 0 0]  30;   //Set point para Tmed
// CS_gain		CS_gain   	[0 0 0 0 0 0 0] 0.01;  //Ganancia 



